import { ActionIcon, Flex, useMantineColorScheme } from '@mantine/core'
import { IconArrowBackUp, IconArrowsMove, IconCircle, IconExclamationCircle, IconLine, IconPoint, IconPolygon, IconRuler, IconTransformPoint } from '@tabler/icons-react'
import { getDraw, setCurrentTool, useMapStore } from '../../../store/map';
import { saveFeatures } from '../mapUtils';

const MapToolbar = ({
    map_id
}: { map_id: string }) => {
    const { currentTool } = useMapStore().id[map_id]
    const { colorScheme } = useMantineColorScheme();

    return (
        <Flex>
            <ActionIcon.Group orientation='vertical' style={{ zIndex: 1, backdropFilter: 'blur(8px)', backgroundColor: colorScheme === 'light' ? '#FFFFFFAA' : '#000000AA', borderRadius: '4px' }}>
                <ActionIcon size='lg' variant='transparent' onClick={() => saveFeatures(map_id)}>
                    <IconExclamationCircle />
                </ActionIcon>

                <ActionIcon size='lg' variant='transparent' onClick={() => getDraw(map_id)?.removeLastPoint()}>
                    <IconArrowBackUp />
                </ActionIcon>

                <ActionIcon
                    size='lg'
                    variant={currentTool === 'Edit' ? 'filled' : 'transparent'}
                    onClick={() => {
                        setCurrentTool(map_id, 'Edit')
                    }}>
                    <IconTransformPoint />
                </ActionIcon>

                <ActionIcon
                    size='lg'
                    variant={currentTool === 'Point' ? 'filled' : 'transparent'}
                    onClick={() => {
                        setCurrentTool(map_id, 'Point')
                    }}>
                    <IconPoint />
                </ActionIcon>

                <ActionIcon
                    size='lg'
                    variant={currentTool === 'LineString' ? 'filled' : 'transparent'}
                    onClick={() => {
                        setCurrentTool(map_id, 'LineString')
                    }}>
                    <IconLine />
                </ActionIcon>

                <ActionIcon
                    size='lg'
                    variant={currentTool === 'Polygon' ? 'filled' : 'transparent'}
                    onClick={() => {
                        setCurrentTool(map_id, 'Polygon')
                    }}>
                    <IconPolygon />
                </ActionIcon>

                <ActionIcon
                    size='lg'
                    variant={currentTool === 'Circle' ? 'filled' : 'transparent'}
                    onClick={() => {
                        setCurrentTool(map_id, 'Circle')
                    }}>
                    <IconCircle />
                </ActionIcon>

                <ActionIcon
                    size='lg'
                    variant={currentTool === 'Mover' ? 'filled' : 'transparent'}
                    onClick={() => {
                        setCurrentTool(map_id, 'Mover')
                    }}
                >
                    <IconArrowsMove />
                </ActionIcon>

                <ActionIcon
                    size='lg'
                    variant={currentTool === 'Measure' ? 'filled' : 'transparent'}
                    onClick={() => {
                        setCurrentTool(map_id, 'Measure')
                    }}>
                    <IconRuler />
                </ActionIcon>
            </ActionIcon.Group>
        </Flex>
    )
}

export default MapToolbar